@@ -9,8 +9,16 @@ setMethod ('print' , 'Raster',
 			nc <- open.ncdf(x@file@name)
 			print(nc)
 			close.ncdf(nc)
-		}
-		else callNextMethod(x, ...)
+		} else if (is.factor(x)) {
+			cat('factor levels (value attributes)\n')
+			f <- x@data@attributes[[1]]
+			if (nrow(f) > 15) { 
+				f <- f[1:15,]
+			}
+			print(f)
+			# cat('levels      :' , paste(object@data@levels, collapse=', '), '\n')
+			# cat('labels      :' , paste(object@data@labels, collapse=', '), '\n')
+		} else callNextMethod(x, ...)
 	}
 )
 
@@ -55,21 +63,16 @@ setMethod ('show' , 'RasterLayer',
 #		if (dataContent(object) == 'nodata') { cat('vals in mem : none', '\n')
 #		} else { cat('vals in mem :', dataContent(object) , '\n') }
 						
-		if (is.factor(object)) {
-			cat('levels      :' , paste(object@data@levels, collapse=', '), '\n')
-			cat('labels      :' , paste(object@data@labels, collapse=', '), '\n')
-		} else {
-			if (object@data@haveminmax) {
-				cat('min value   :' , minValue(object), '\n')
-				cat('max value   :' , maxValue(object), '\n')
-			} else { 
-				if (object@data@fromdisk) {
-					cat('min value   : ? \n')
-					cat('max value   : ? \n')
-				} else {
-					cat('min value   : NA \n')
-					cat('max value   : NA \n')		
-				}
+		if (object@data@haveminmax) {
+			cat('min value   :' , minValue(object), '\n')
+			cat('max value   :' , maxValue(object), '\n')
+		} else { 
+			if (object@data@fromdisk) {
+				cat('min value   : ? \n')
+				cat('max value   : ? \n')
+			} else {
+				cat('min value   : NA \n')
+				cat('max value   : NA \n')		
 			}
 		}
 		cat('projection  :' , projection(object, TRUE), '\n')
